package diplomka.pef.czu.diplomka.main;

import android.Manifest;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.pm.PackageManager;
import android.net.wifi.ScanResult;
import android.net.wifi.WifiManager;
import android.os.AsyncTask;
import android.os.Build;
import android.os.Bundle;
import android.support.v4.app.ActivityCompat;
import android.support.v7.app.AppCompatActivity;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.Toast;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import czu.pef.diplomka.R;
import diplomka.pef.czu.diplomka.NetworkList.NetworkInfo;
import diplomka.pef.czu.diplomka.NetworkList.INetworksListItem;
import diplomka.pef.czu.diplomka.NetworkList.MyNetworkListAdapter;
import diplomka.pef.czu.diplomka.NetworkList.NetworkName;
import diplomka.pef.czu.diplomka.other.NetworklistReciever;

/**
 * Created by Roman on 18.2.2018.
 */

public class NetworkSelectActivity extends AppCompatActivity implements AdapterView.OnItemClickListener,ActivityCompat.OnRequestPermissionsResultCallback {

    private WifiManager mWifiManager;
    private ListView mListView = null;
    private ArrayList<INetworksListItem> mListItems;
    private MyNetworkListAdapter mAdapter;
    /* every index 'i' is TRUE/FALSE depending on item 'i' in listView is selected or not */
    private boolean selectedItems[];
    public static int PERMISSIONS_REQUEST_CODE_ACCESS_COARSE_LOCATION =120;
    private int numberOfSelected=0;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        init();

        if(Build.VERSION.SDK_INT >= Build.VERSION_CODES.M && ActivityCompat.checkSelfPermission(this, Manifest.permission.ACCESS_COARSE_LOCATION)!= PackageManager.PERMISSION_GRANTED){
            ActivityCompat.requestPermissions(this,new String[]{Manifest.permission.ACCESS_COARSE_LOCATION},
                    PERMISSIONS_REQUEST_CODE_ACCESS_COARSE_LOCATION);
            //After this point you wait for callback in onRequestPermissionsResult(int, String[], int[]) overriden method
        }
    }

    private void init(){
        setContentView(R.layout.select_networks_list);
        mListView = (ListView)findViewById(R.id.networksList);

        mWifiManager = (WifiManager) getApplicationContext().getSystemService(WIFI_SERVICE);
        checkWifiStatus();

        registerReceiver(mWifiReceiver, new IntentFilter(WifiManager.RSSI_CHANGED_ACTION));
        mWifiManager.startScan();
        doScan(getCurrentFocus());
    }

    //check/turnOn wifi
    private void checkWifiStatus(){
        if (mWifiManager.isWifiEnabled() == false){
            Toast.makeText(getApplicationContext(), "Zapinam WIFI",
                    Toast.LENGTH_LONG).show();
            mWifiManager.setWifiEnabled(true);
        }

    }

    /* make new scan via AsyncTask thread*/
    public void doScan(View view){
        new NetworkSelectActivity.FindAccesPointsTask().execute(this);
    }

    @SuppressWarnings("rawtypes")
    @Override
    public void onItemClick(AdapterView arg0, View arg1,int position,long arg3){

        if(selectedItems[position]==false){
            selectedItems[position]=true;
            numberOfSelected++;
        } else{
            selectedItems[position]=false;
            numberOfSelected--;
        }
    }

    //select all items
    public void selectAll(View view){
        for(int i=0;i< mListItems.size();i++){
            if(mListItems.get(i).isSection()==false)
                mListView.setItemChecked(i, true);
            numberOfSelected++;
        }
        Arrays.fill(selectedItems , true);
    }

    //select non items
    public void selectNon(View view){
        for(int i=0;i< mListItems.size();i++){
            if(mListItems.get(i).isSection()==false)
                mListView.setItemChecked(i, false);
            numberOfSelected--;
        }
        Arrays.fill(selectedItems , false);
    }

    /* start new activity */
    public void startThroughputMeasuringActivity(View view){

        if(numberOfSelected==0){
            Toast.makeText(getApplicationContext(), "Vyberte site",
                    Toast.LENGTH_LONG).show();
            return;
        }
        Intent intent = new Intent(this, ThroughputMeasuringActivity.class);
        intent.putParcelableArrayListExtra("networks", getSelectedNetworks());
        intent.putExtra("interval",  getIntent().getExtras().getLong("interval"));
        intent.putExtra("csvFileName",  getIntent().getExtras().getString("csvFileName"));
        startActivity(intent);
    }


    /* return String array of selected APs MAC address */
    public ArrayList<NetworkInfo> getSelectedNetworks(){
        ArrayList<NetworkInfo> checked = new ArrayList<NetworkInfo>(numberOfSelected);

        for(int i=0;i<mListItems.size();i++){

            if(selectedItems[i]){

                if(!mListItems.get(i).isSection() && !mListItems.get(i).isNonSelcetableItem()){
                    checked.add((NetworkInfo)mListItems.get(i));
                }
            }
        }
        return checked;
    }

    @Override
    protected void onPause(){
        super.onPause();
        unregisterReceiver(mWifiReceiver);
        //LocalBroadcastManager.getInstance(this).unregisterReceiver(mWifiReceiver);
    }

    @Override
    protected void onResume() {
        super.onResume();
        //init();
        registerReceiver(mWifiReceiver, new IntentFilter(WifiManager.RSSI_CHANGED_ACTION));
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        //unregisterReceiver(mWifiReceiver);
    }


    @Override
    public void onRequestPermissionsResult(int requestCode, String[] permissions,
                                           int[] grantResults) {
        if (requestCode == PERMISSIONS_REQUEST_CODE_ACCESS_COARSE_LOCATION && grantResults[0] == PackageManager.PERMISSION_GRANTED) {

            // Do something with granted permission
            mWifiManager.getScanResults();
        }
    }

    //start broadcast Receiver
    private BroadcastReceiver mWifiReceiver =new BroadcastReceiver(){

        @Override
        public void onReceive(Context context, Intent intent) {

            NetworklistReciever.recieveNewData(mWifiManager, mListItems, mAdapter);
        }
    };//end broadcast recEIver


    /*
	 * start of subclass FindAccesPointTask
	 * scanning wifi networks and filling listView via asyncTask
	 */
    private class FindAccesPointsTask extends AsyncTask<NetworkSelectActivity, Void, NetworkSelectActivity>{

        @Override
        protected void onPreExecute() {
            checkWifiStatus();
            mListItems = new ArrayList<INetworksListItem>();
            mWifiManager.startScan();
        }



        @Override
        protected NetworkSelectActivity doInBackground(NetworkSelectActivity... params) {

            List<ScanResult> scanResults = mWifiManager.getScanResults();
			/*
			 * hashMap of networks and theirs AccesPoints
			 * key - String = network SSID
			 * value - ArrayList<AccessPoint> = list of AccesPoints for each network(for each key)
			 */
            final HashMap<String, NetworkInfo> networksHash = new HashMap<String,NetworkInfo>();
            NetworkInfo currentnetInfo;

            for(int i=0; i<scanResults.size();i++){
                if(networksHash.containsKey(scanResults.get(i).SSID)){
                    String actualNetworkName = scanResults.get(i).SSID;
                    currentnetInfo = networksHash.get(actualNetworkName);
                    //pokud ma sit silnejsi signal zobrazime ho v seznamu misto puvodniho
                    if(scanResults.get(i).level > currentnetInfo.getLevel()){
                        NetworkInfo nI = new NetworkInfo(scanResults.get(i).SSID,scanResults.get(i).frequency,scanResults.get(i).level,scanResults.get(i).SSID,scanResults.get(i).capabilities);
                        networksHash.put(actualNetworkName, nI);
                    }

                }else{
                    String actualNetworkName = scanResults.get(i).SSID;
                    //currentnetInfo = new NetworkInfo();
                    NetworkInfo nI = new NetworkInfo(scanResults.get(i).SSID,scanResults.get(i).frequency,scanResults.get(i).level,scanResults.get(i).SSID,scanResults.get(i).capabilities);
                    networksHash.put(actualNetworkName, nI);
                }
            }

            // filling listView
            if (networksHash.isEmpty()) {
                mListItems.add(new NetworkName("Nenalezeny zadne site"));
            } else {

                for (String key : networksHash.keySet()) {
                    currentnetInfo = networksHash.get(key);
                    //int count = currentApList.size();
                   // if(key==null || key.equals("")) key="'hidden ssid'";
                    //String siteName = key;
                    //NetworkName currNetwork = new NetworkName(siteName);
                    //currNetwork.setAccessPointsCount(count);
                    //mListItems.add(currNetwork);

                   /* for(NetworkInfo nI : currentApList){
                        mListItems.add(nI);

                    }*/
                   mListItems.add(currentnetInfo);
                }
            }

			/* Inicialization of selectedItems array to 'false' values */
            selectedItems = new boolean[mListItems.size()];
            Arrays.fill(selectedItems , false);

            return params[0];
        }



        @Override
        protected void onPostExecute(NetworkSelectActivity result) {
            mAdapter = new MyNetworkListAdapter(result, mListItems);
            mListView.setAdapter(mAdapter);
            mListView.setOnItemClickListener(result);
        }

    }//end of FIndAccesPointTask subclass




}


